pub struct Package {
    pub scheduled_package_id: Box<ScheduledPackageId>,
    pub package_dimensions: Box<Dimensions>,
    pub package_weight: Box<Weight>,
    pub package_items: Option<Vec<Item>>,
    pub package_time_slot: Box<TimeSlot>,
    pub package_identifier: Option<String>,
    pub invoice: Option<Box<InvoiceData>>,
    pub package_status: Option<PackageStatus>,
    pub tracking_details: Option<Box<TrackingDetails>>,
}
Package : A package. This object contains all the details of the scheduled Easy Ship package including the package identifier, physical attributes such as dimensions and weight, selected time slot to handover the package to carrier, status of the package, and tracking/invoice details.

Fields

scheduled_package_id: Box<ScheduledPackageId>package_dimensions: Box<Dimensions>package_weight: Box<Weight>package_items: Option<Vec<Item>>

A list of items contained in the package.

package_time_slot: Box<TimeSlot>package_identifier: Option<String>

Optional seller-created identifier that is printed on the shipping label to help the seller identify the package.

invoice: Option<Box<InvoiceData>>package_status: Option<PackageStatus>tracking_details: Option<Box<TrackingDetails>>

Implementations

A package. This object contains all the details of the scheduled Easy Ship package including the package identifier, physical attributes such as dimensions and weight, selected time slot to handover the package to carrier, status of the package, and tracking/invoice details.